@@ -128,7 +128,7 @@ class Plot:
         self.vmax = None
 
     def __repr__(self):
-        return f'Plot(grid={self.grid}, xgrid={self.xgrid}, _series={self._series})'
+        return f'Plot(width={self.width}, height={self.height}, offset={self.offset}, left={self.left}, right={self.right}, grid={self.grid}, xgrid={self.xgrid}, vmin={self.vmin}, vmax={self.vmax}, _series={self._series})'
 
     # Series handling.
     def series(self, n):
@@ -195,6 +195,8 @@ class Plot:
         if vmin is None or vmax is None:
             return None
         delta = vmax - vmin
+        if delta <= 0:
+            return None
         digits = int(math.log(delta) / math.log(10))
         return 10**digits
 
@@ -205,21 +207,24 @@ class Plot:
             vmin = self.vmin
         if vmax is None:
             vmax = self.vmax
+        if vmax - vmin < grid:
+            return
         # How many grid lines should be drawn?
         ngrids = vmin / grid
         n = int(ngrids)
-        frac = vmin - grid * n
+        remainder = vmin - grid * n
         # FIXME: Fail if vmin is negative?
-        v = self.vmin - grid * frac
+        v = self.vmin - grid * remainder
         while v < vmax:
-            yield v
+            if vmin <= v:
+                yield v
             v += grid
 
     def draw_grid(self, grid, color):
         """Draw grids for y-axis.  The interval between grids is spcified by
         GRID.  Its color is specified by COLOR."""
         # How many grid lines should be drawn?
-        for v in self.find_grids():
+        for v in self.find_grids(grid):
             y = self.to_y_coordinate(v)
             # FIXME: It's better to control the brightntess with alpha channel.
             self.screen.draw_line(0,
@@ -229,10 +234,10 @@ class Plot:
                                   color,
                                   offset=self.offset)
 
-    def draw_xgrid(self, grid, color):
+    def draw_xgrid(self, xgrid, color):
         sr = self.series(0)
         xl, xr = sr[self.left], sr[self.right]
-        for v in self.find_grids(self.xgrid, xl, xr):
+        for v in self.find_grids(xgrid, xl, xr):
             x = int(self.width * (v - xl) / (xr - xl))
             self.screen.draw_line(x,
                                   0,
@@ -267,8 +272,12 @@ class Plot:
         self.update_minmax(series)
         # Draw grid line.
         if self.grid:
+            if not self.screen.curses:
+                self.draw_grid(self.grid / 2, DARK_GRAY)
             self.draw_grid(self.grid, GRAY)
         if self.xgrid:
+            if not self.screen.curses:
+                self.draw_xgrid(self.xgrid / 2, DARK_GRAY)
             self.draw_xgrid(self.xgrid, GRAY)
         # Draw all series.
         for sr in series:
@@ -276,16 +285,18 @@ class Plot:
         # Draw legends.
         self.draw_legends()
         # Display the maximum and the minimum values.
-        self.screen.draw_text(self.width - FONT_SIZE * 5,
+        self.screen.draw_text(-FONT_SIZE * 5,
                               0,
                               f'{self.vmax:8.2f}',
                               self.start_color,
-                              offset=self.offset)
-        self.screen.draw_text(self.width - FONT_SIZE * 5,
-                              self.height - FONT_SIZE * 2,
+                              offset=self.offset,
+                              plot=self)
+        self.screen.draw_text(-FONT_SIZE * 5,
+                              -FONT_SIZE * 2,
                               f'{self.vmin:8.2f}',
                               self.start_color,
-                              offset=self.offset)
+                              offset=self.offset,
+                              plot=self)
 
     @cache
     def create_background(self):
@@ -304,8 +315,9 @@ class Plot:
     def draw_background(self):
         """Fill the background with gradient colors."""
         # FIXME: Should not re-generate at every drawing.
-        bg = self.create_background()
-        self.screen.screen.blit(bg, self.offset)
+        if not self.screen.curses:
+            bg = self.create_background()
+            self.screen.screen.blit(bg, self.offset)
 
 class Screen:
     def __init__(self,
@@ -425,23 +437,36 @@ class Screen:
                   color=0,
                   size=FONT_SIZE,
                   offset=None,
+                  plot=None,
                   _cache=[]):
         """Display a text TEXT at the location of (X, Y).  Font size and color
         can be specified with COLOR and SIZE."""
         if offset is None:
             offset = 0, 0
         dx, dy = offset
-        x, y = x + dx, y + dy
         if not self.curses:
+            # Negative coordinate indicates the distance from the oppsosite edge.
+            if x < 0:
+                x = self.width + x
+            if y < 0:
+                y = self.height + y
             font = self.load_font('Courier', size, bold=True)
             rgba = self.color_rgba(color)
             # The second parameter True means enabling antialiasing.
             text = font.render(text, True, rgba, BLACK)
-            self.screen.blit(text, (x, y))
+            self.screen.blit(text, (dx + x, dy + y))
         else:
+            if len(text) >= 2:
+                # Negative coordinate indicates the distance from the oppsosite edge.
+                if x < 0:
+                    x = plot.width * FONT_SIZE // 2 + x
+                if y < 0:
+                    y = plot.height * FONT_SIZE + y
+                x = int(x // (FONT_SIZE / 2))
+                y = int(y // FONT_SIZE)
             attr = curses.color_pair(1 + color % 7)
             try:
-                self.screen.addstr(y, x, text, attr)
+                self.screen.addstr(dy + y, dx + x, text, attr)
             except:
                 pass
 
@@ -481,4 +506,9 @@ class Screen:
                     return event.unicode
         else:
             # Not necessary in curses mode.
-            pass
+            self.screen.nodelay(True)
+            try:
+                key = self.screen.getkey()
+                return key
+            except:
+                return None
